﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using BSF_Utilities;
using System.Net;
using System.IO;
using System.Text.RegularExpressions;
using System.Threading;

namespace WebMinerDemo
{
    public partial class MainForm : Form
    {
        private string _errorMessage = string.Empty;
        private WebMiner _webMiner = null;

        public MainForm()
        {
            InitializeComponent();
        }

        private void btnDownloadPage_Click(object sender, EventArgs e)
        {
            _webMiner = new WebMiner(txtAdress.Text);
            _webMiner.LookAroundInterated += new BSF_Utilities.WebMiner.LookAroundInteratedEventHandler(_webMiner_LookAroundInterated);
            _webMiner.PageDownloadCompleted += new System.Net.OpenReadCompletedEventHandler(webMiner_PageDownloadComplete);
            _webMiner.DownloadWebpage();
        }

        private void _webMiner_LookAroundInterated(object sender, BSF_Utilities.WebMiner.LookAroundInteratedEventArgs e)
        {
            int start = txtPageContent.GetFirstCharIndexFromLine(e.CurrentLine);
            int end = txtPageContent.GetFirstCharIndexFromLine(e.CurrentLine);
            end += txtPageContent.Lines[e.CurrentLine].Length;
            txtPageContent.SelectionStart = start;
            txtPageContent.SelectionLength = end - start;
            txtPageContent.ScrollToCaret();
            Thread.Sleep(700);
        }

        private void webMiner_PageDownloadComplete(object sender, OpenReadCompletedEventArgs e)
        {
            if (e.Error != null)
            {
                MessageBox.Show(e.Error.Message, Application.ProductName,
                    MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            else
            {
                txtPageContent.Lines = ((WebMiner)sender).PageToMineContent;

                foreach (Control control in this.Controls)
                {
                    control.Enabled = true;
                }
            }
        }

        private void btnGo_Click(object sender, EventArgs e)
        {
            int line = -1;
            Match match = _webMiner.LookFor(txtSearchTerm.Text, WebMiner.RecommendedOptions, out line);

            if (match != null)
            {
                int index = txtPageContent.GetFirstCharIndexFromLine(line);
                txtPageContent.SelectionStart = match.Index + index;
                txtPageContent.SelectionLength = match.Length;
            }
            else
            {
                MessageBox.Show("No matches found!");
            }
        }

        private void btnLookAroundGo_Click(object sender, EventArgs e)
        {
            WebMiner.LookAroundParams.LookDirection direction;

            if (radioBoth.Checked)
            {
                direction = WebMiner.LookAroundParams.LookDirection.Both;
            }
            else if (radioDown.Checked)
            {
                direction = WebMiner.LookAroundParams.LookDirection.Down;
            }
            else
            {
                direction = WebMiner.LookAroundParams.LookDirection.Up;
            }

            WebMiner.LookAroundParams lookingParams = new WebMiner.LookAroundParams(txtLookAroundTerm.Text, 
                txtLookAroundSearchTerm.Text, (int)nudLookingRadius.Value, direction);

            _webMiner.LookAroundParameters = lookingParams;

            int line = -1;
            Match match = _webMiner.LookAroundFor(RegexOptions.IgnoreCase, out line);

            if (match != null)
            {
                int index = txtPageContent.GetFirstCharIndexFromLine(line);
                txtPageContent.SelectionStart = match.Index + index;
                txtPageContent.SelectionLength = match.Length;
            }
        }

        private void btnTestHelpers_Click(object sender, EventArgs e)
        {
            TestHelperForm frmTestHelpers = new TestHelperForm();
            frmTestHelpers.ShowDialog();
        }
    }
}
